@@ -7,6 +7,9 @@ PROFILER_PROFILE_ID = __module_name__
 THREADED = u'Threaded'
 SERVER_THREADING_KEY = u'PyHTTPIntercept/Threading'
 
+SERVER_REQUEST_TIMEOUT = u'PyHTTPIntercept/Request Timeout'
+DEFAULT_SERVER_REQUEST_TIMEOUT = 1.5
+
 START_SERVERS = u'Start WebServers'
 STOP_SERVERS = u'Stop WebServers'
 
