@@ -29,6 +29,7 @@ def register_https_allowed_domain_cfg():
     cfg.register(config=HTTPS_DOMAIN_CFG,
                  config_type=cfg_params.CONST.json,
                  template=TEMPLATE,
-                 schema=schema.request_schema.https_domains)
+                 schema=schema.request_schema.https_domains,
+                 upgrade_merge_template=True)
 
     return cfg
