@@ -6,7 +6,7 @@ from ..frame.server_config import ServerConfigFrame
 
 class _ServerConfigWindow(object):
 
-    def _setup(self):
+    def _draw_widgets(self):
         self.title(u'WebServer Config')
         self.dynamic_frame = ServerConfigFrame(parent=self._main_frame)
 
