@@ -77,3 +77,55 @@ def run_ad_hoc_modifier(module,
     del cfg[CFG_ROOT]
 
     return response
+
+
+def run_ad_hoc_uri_modifier(module,
+                            uri,
+                            filter='',
+                            override='',
+                            params=''):
+    """
+    Runs an intercept uri modifier standalone
+
+    :param module: python module object
+    :param uri: uri to modify
+    :param filter: string to match against uri
+    :param override: string
+    :param params: json string or an object that can be json.dumps-ed
+    :return:
+    """
+
+    if isinstance(params, (list, dict, int, float)):
+        params = json.dumps(params)
+
+    cfg = register_scenario_config()
+
+    cfg[CFG_ROOT] = {
+        ScenarioConstant.modifiers: [
+            {
+                ModifierConstant.handler: "",
+                ModifierConstant.modifier: "",
+                ModifierConstant.active: False,
+                ModifierConstant.filter: "",
+                ModifierConstant.override: "",
+                ModifierConstant.params: ""
+            }
+        ],
+        ScenarioConstant.description: u'FOR DEBUG: DO NOT USE / CHANGE'
+    }
+
+    modifier = Modifier(cfg_fn=register_scenario_config,
+                        cfg_root=MOD_ROOT,
+                        key=0)
+    modifier.update({ModifierConstant.params: params,
+                     ModifierConstant.filter: filter,
+                     ModifierConstant.override: override})
+    try:
+        modified_uri = module.modify(uri=uri,
+                                     modifier=modifier)
+    except Exception as e:
+        logging.exception(e)
+
+    del cfg[CFG_ROOT]
+
+    return modified_uri
