@@ -232,6 +232,35 @@ def decorate_for_json_parameters(func):
     return wrapper
 
 
+# ------------------------------------------------------------------------------
+
+def decorate_uri_modifier_for_json_parameters(func):
+
+    """
+    Calls the modifier after extracting the parameters as a json string and
+    converting to a python object (integer, float, string, list or dictionary)
+
+    e.g. parameters[u'parameters'] == '{"a": [1, 2, 3], "b": "some string"}'
+    is converted to parameters[u'parameters'] == {u'a': [1, 2, 3], u'b': u'some string'}
+    """
+    @wraps(func)
+    def wrapper(uri,
+                modifier,
+                **kwargs):
+
+        # logging.debug(u'in decorate_for list parameters')
+
+        parse_json_parameters(modifier)
+
+        modified_uri = func(uri=uri,
+                            modifier=modifier,
+                            **kwargs)
+
+        return modified_uri
+
+    return wrapper
+
+
 # ------------------------------------------------------------------------------
 
 
@@ -270,6 +299,32 @@ def decorate_for_json_modifier(func):
 # ------------------------------------------------------------------------------
 
 
+def decorate_uri_modifier_for_filter(func):
+
+    u"""
+    Calls the modifier if the bookmark in the filter is in the request
+    """
+
+    @wraps(func)  # Added to maintain modifier's docstring
+    def wrapper(uri,
+                modifier,
+                **kwargs):
+
+        filter = modifier[ModifierConstant.filter]
+
+        if modifier.passes_filter(value=uri,
+                                  wildcards=u''):
+            uri = func(uri=uri,
+                       modifier=modifier,
+                       **kwargs)
+
+        return uri
+
+    return wrapper
+
+# ------------------------------------------------------------------------------
+
+
 def decorate_for_uri_filter(func):
 
     u"""
