@@ -16,12 +16,12 @@ logging = logging_helper.setup_logging()
 
 
 def modify(uri,
-           parameters):
+           modifier):
 
-    string_to_match = parameters.filter
-    replacement_value = (parameters.override
-                         if parameters.override
-                         else parameters.params)
+    string_to_match = modifier.filter
+    replacement_value = (modifier.override
+                         if modifier.override
+                         else modifier.params)
 
     uri = uri.replace(string_to_match,
                       replacement_value)
