@@ -32,7 +32,10 @@ class PostHandler(BaseRequestHandler):
         # except:
         #     pass
 
-        content_length = int(self._request.headers.getheader(u'content-length', -1))
+        try:
+            content_length = int(self._request.headers.getheader(u'content-length', -1))  # Py2
+        except AttributeError:
+            content_length = int(self._request.headers.get(u'content-length', -1))  # Py3
 
         if content_length != -1:
             body = self._request.rfile.read(content_length)
